summaryrefslogtreecommitdiff
path: root/lisp/delim-col.el
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2011-12-11 21:32:49 -0800
committerPaul Eggert <eggert@cs.ucla.edu>2011-12-11 21:32:49 -0800
commit333f9019e29e9b6de3a7ec07448be1d364ba540b (patch)
treefd19625604abbd2784e9c9de92c613ff965ea11d /lisp/delim-col.el
parent11636b221d2897aed5ca9a762d7b61afd20b6168 (diff)
downloademacs-333f9019e29e9b6de3a7ec07448be1d364ba540b.tar.gz
Spelling fixes.
Diffstat (limited to 'lisp/delim-col.el')
-rw-r--r--lisp/delim-col.el14
1 files changed, 7 insertions, 7 deletions
diff --git a/lisp/delim-col.el b/lisp/delim-col.el
index 96a0745dd31..a0a8af80389 100644
--- a/lisp/delim-col.el
+++ b/lisp/delim-col.el
@@ -97,7 +97,7 @@
;; operates over the text rectangle selected which rectangle diagonal is
;; given by the region start and end.
;;
;; See `delimit-columns-format' variable documentation for column formating.
;;
;; `delimit-columns-region' is useful when you have columns of text that
;; are not well aligned, like:
@@ -171,7 +171,7 @@ For examples below, consider:
Valid values are:
- nil no formating. That is, `delimit-columns-after' is followed by
+ nil no formatting. That is, `delimit-columns-after' is followed by
`delimit-columns-separator'.
For example, the result is: \"<ccc>:<dddd>:\"
@@ -190,9 +190,9 @@ Valid values are:
For example, the result is: \"<ccc >:<dddd >:\"
Any other value is treated as t."
- :type '(choice :menu-tag "Column Formating"
- :tag "Column Formating"
- (const :tag "No Formating" nil)
+ :type '(choice :menu-tag "Column Formatting"
+ :tag "Column Formatting"
+ (const :tag "No Formatting" nil)
(const :tag "Column Alignment" t)
(const :tag "Separator Alignment" separator)
(const :tag "Column Padding" padding))
@@ -404,7 +404,7 @@ START and END delimits the corners of text rectangle."
(re-search-forward delimit-columns-separator
delimit-columns-limit 'move))
(setq ncol (1+ ncol)))
;; insert first formating
(insert delimit-columns-str-before delimit-columns-before)
;; Adjust all columns but last one
(while (progn
@@ -436,7 +436,7 @@ START and END delimits the corners of text rectangle."
(setq spaces (and delimit-columns-format
(make-string (aref delimit-columns-max ncol)
?\s)))))
;; insert last formating
(cond ((null delimit-columns-format)
(insert delimit-columns-after delimit-columns-str-after))
((eq delimit-columns-format 'padding)
@@ -97,7 +97,7 @@
;; given by the region start and end.
;;
-;; See `delimit-columns-format' variable documentation for column formating.
+;; See `delimit-columns-format' variable documentation for column formatting.
;;
;; `delimit-columns-region' is useful when you have columns of text that
@@ -404,7 +404,7 @@ START and END delimits the corners of text rectangle."
delimit-columns-limit 'move))
(setq ncol (1+ ncol)))
- ;; insert first formating
+ ;; insert first formatting
(insert delimit-columns-str-before delimit-columns-before)
;; Adjust all columns but last one
@@ -436,7 +436,7 @@ START and END delimits the corners of text rectangle."
(make-string (aref delimit-columns-max ncol)
?\s)))))
- ;; insert last formating
+ ;; insert last formatting
(cond ((null delimit-columns-format)
(insert delimit-columns-after delimit-columns-str-after))